@@ -8,6 +8,7 @@ import random
 import fcntl
 import termios
 import struct
+import subprocess as sp
 
 from os.path import dirname, join
 from os import environ
@@ -114,7 +115,11 @@ class Doge(object):
         files = filter(
             lambda s: s[0] != '.', os.listdir(os.environ.get('HOME'))
         )
-        self.real_data.append(random.choice(list(files)))  # wow so many file
+        files = list(files)
+
+        # wow so many file
+        if files:
+            self.real_data.append(random.choice(files))
 
         for proc in self.get_processes():
             if proc in self.known_processes:
@@ -125,28 +130,23 @@ class Doge(object):
         self.real_data = list(map(str.lower, self.real_data))
 
     def get_processes(self):
-        # wow such not psutil
-        # such doge now without dependansy
-        if not os.path.isdir('/proc'):
-            return []
-
-        pids = [pid for pid in os.listdir('/proc') if pid.isdigit()]
-        random.shuffle(pids)
-
         procs = set()
-        for pid in pids:
-            try:
-                with open(join('/proc', pid, 'cmdline'), 'r') as cmd:
-                    name = cmd.read()
-                    name = name.split(' ')[0]
-                    name = name.split("\x00")[0]  # many null byte
-                    name = name.split('/')[-1]
-            except IOError:  # wut gone
-                continue
-            if name:
-                procs.add(name)
 
-        return procs
+        try:
+            p = sp.Popen(['ps', '-A', '-o', 'comm='], stdout=sp.PIPE)
+            output, error = p.communicate()
+
+            if sys.version_info > (3, 0):
+                output = output.decode('utf-8')
+
+            for comm in output.split('\n'):
+                name = comm.split('/')[-1]
+                if name:
+                    procs.add(name)
+
+        finally:
+            # wow no ps or many error
+            return procs
 
     def generate(self):
         for line in self.lines:
